/*
 * Copyright 1988 by the Massachusetts Institute of Technology.
 *
 * For copying and distribution information, please see the file
 * <mit-copyright.h>.
 *
 * Machine-type definitions: IBM 032 (RT/PC)
 */

#include <mit-cpyright.h>

#define BSDUNIX
#define IBMWS
#define IBMWSASM
#define BITS32
#define BIG
#define MSBFIRST
#define MUSTALIGN
